Class: Google4R::Checkout::CancelItemsCommand

Inherits:
ItemsCommand show all
Defined in:
lib/google4r/checkout/commands.rb

Overview

The command lets you specify that one or more specific items in an order have been cancelled, meaning they will not be delivered to the customer.

Constant Summary

Constants inherited from Command

Google4R::Checkout::Command::CHECKOUT_API_URL, Google4R::Checkout::Command::ORDER_PROCESSING_API_URL, Google4R::Checkout::Command::PRODUCTION_URL_PREFIX, Google4R::Checkout::Command::SANDBOX_URL_PREFIX

Instance Attribute Summary collapse

Attributes inherited from ItemsCommand

#item_info_arr, #send_email

Attributes inherited from Command

#command_tag_name, #frontend, #google_order_number

Instance Method Summary collapse

Methods inherited from ItemsCommand

#initialize

Methods inherited from Command

#initialize, #send_to_google_checkout

Constructor Details

This class inherits a constructor from Google4R::Checkout::ItemsCommand

Instance Attribute Details

#commentObject

An optional comment related to one or more canceled line items



492
493
494
# File 'lib/google4r/checkout/commands.rb', line 492

def comment
  @comment
end

#reasonObject

The reason that you are canceling one or more line items



489
490
491
# File 'lib/google4r/checkout/commands.rb', line 489

def reason
  @reason
end

Instance Method Details

#to_xmlObject



494
495
496
# File 'lib/google4r/checkout/commands.rb', line 494

def to_xml
  CancelItemsCommandXmlGenerator.new(self).generate
end