Class: Google4R::Checkout::CheckoutRedirectResponse
- Inherits:
-
Object
- Object
- Google4R::Checkout::CheckoutRedirectResponse
- Defined in:
- lib/google4r/checkout/commands.rb
Overview
CheckoutRedirectResponse instances are returned when a CheckoutCommand is successfully processed by Google Checkout.
Instance Attribute Summary collapse
-
#redirect_url ⇒ Object
readonly
The URL to redirect to.
-
#serial_number ⇒ Object
readonly
The serial number of the
response.
Instance Method Summary collapse
-
#initialize(serial_number, redirect_url) ⇒ CheckoutRedirectResponse
constructor
Create a new CheckoutRedirectResponse with the given serial number and redirection URL.
- #to_s ⇒ Object
Constructor Details
#initialize(serial_number, redirect_url) ⇒ CheckoutRedirectResponse
Create a new CheckoutRedirectResponse with the given serial number and redirection URL. Do not create CheckoutRedirectResponse instances in your own code. Google4R creates them for you.
290 291 292 293 |
# File 'lib/google4r/checkout/commands.rb', line 290 def initialize(serial_number, redirect_url) @serial_number = serial_number @redirect_url = redirect_url end |
Instance Attribute Details
#redirect_url ⇒ Object (readonly)
The URL to redirect to.
285 286 287 |
# File 'lib/google4r/checkout/commands.rb', line 285 def redirect_url @redirect_url end |
#serial_number ⇒ Object (readonly)
The serial number of the
282 283 284 |
# File 'lib/google4r/checkout/commands.rb', line 282 def serial_number @serial_number end |
Instance Method Details
#to_s ⇒ Object
295 296 297 |
# File 'lib/google4r/checkout/commands.rb', line 295 def to_s return @redirect_url end |