Class: Google4R::Checkout::CreateOrderRecurrenceRequestCommand

Inherits:
Command
  • Object
show all
Defined in:
lib/google4r/checkout/commands.rb

Overview

The tag contains a request to charge a customer for one or more items in a subscription.

Constant Summary

Constants inherited from Command

Google4R::Checkout::Command::CHECKOUT_API_URL, Google4R::Checkout::Command::ORDER_PROCESSING_API_URL, Google4R::Checkout::Command::PRODUCTION_URL_PREFIX, Google4R::Checkout::Command::SANDBOX_URL_PREFIX

Instance Attribute Summary collapse

Attributes inherited from Command

#command_tag_name, #frontend

Instance Method Summary collapse

Methods inherited from Command

#send_to_google_checkout

Constructor Details

#initialize(frontend) ⇒ CreateOrderRecurrenceRequestCommand

Initialize a new CreateOrderRecurrenceRequestCommand with a fresh ShoppingCart.



437
438
439
440
# File 'lib/google4r/checkout/commands.rb', line 437

def initialize(frontend)
  super(frontend)
  @shopping_cart = ShoppingCart.new(self)
end

Instance Attribute Details

#google_order_numberObject

The ID that uniquely identifies this order



432
433
434
# File 'lib/google4r/checkout/commands.rb', line 432

def google_order_number
  @google_order_number
end

#shopping_cartObject (readonly)

Returns the value of attribute shopping_cart.



434
435
436
# File 'lib/google4r/checkout/commands.rb', line 434

def shopping_cart
  @shopping_cart
end

Instance Method Details

#to_xmlObject



442
443
444
# File 'lib/google4r/checkout/commands.rb', line 442

def to_xml
  CreateOrderRecurrenceRequestCommandXmlGenerator.new(self).generate
end