Class: Google4R::Checkout::DeliverOrderCommand

Inherits:
Command
  • Object
show all
Defined in:
lib/google4r/checkout/commands.rb

Overview

The DeliverOrderCommand indicates that Google should update an order's fulfillment order state to DELIVERED

Constant Summary

Constants inherited from Command

Command::CHECKOUT_API_URL, Command::ORDER_PROCESSING_API_URL, Command::PRODUCTION_URL_PREFIX, Command::SANDBOX_URL_PREFIX

Instance Attribute Summary collapse

Attributes inherited from Command

#command_tag_name, #frontend, #google_order_number

Instance Method Summary collapse

Methods inherited from Command

#initialize, #send_to_google_checkout

Constructor Details

This class inherits a constructor from Google4R::Checkout::Command

Instance Attribute Details

#carrierObject

The name of the company responsible for shipping the item. Valid values for this tag are DHL, FedEx, UPS, USPS and Other.



378
379
380
# File 'lib/google4r/checkout/commands.rb', line 378

def carrier
  @carrier
end

#send_emailObject

if google checkout should email buyer to ssay order is dispatched



374
375
376
# File 'lib/google4r/checkout/commands.rb', line 374

def send_email
  @send_email
end

#tracking_numberObject

The shipper's tracking number that is associated with an order



381
382
383
# File 'lib/google4r/checkout/commands.rb', line 381

def tracking_number
  @tracking_number
end

Instance Method Details

#to_xmlObject



383
384
385
# File 'lib/google4r/checkout/commands.rb', line 383

def to_xml
  DeliverOrderCommandXmlGenerator.new(self).generate
end