Class: Google4R::Checkout::Notification

Inherits:
Object
  • Object
show all
Defined in:
lib/google4r/checkout/notifications.rb

Overview

Abstract class for all the notifications. It should not be instantiated directly.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(frontend) ⇒ Notification

Initializes the RiskInformationNotification instance with the given Frontend instance.



157
158
159
# File 'lib/google4r/checkout/notifications.rb', line 157

def initialize(frontend)
  @frontend = frontend
end

Instance Attribute Details

#frontendObject

The frontend this notification belongs to.



145
146
147
# File 'lib/google4r/checkout/notifications.rb', line 145

def frontend
  @frontend
end

#google_order_numberObject

The Google order number the new order notification belongs to (String).



151
152
153
# File 'lib/google4r/checkout/notifications.rb', line 151

def google_order_number
  @google_order_number
end

#serial_numberObject

The serial number of the new order notification (String).



148
149
150
# File 'lib/google4r/checkout/notifications.rb', line 148

def serial_number
  @serial_number
end

#timestampObject

The timestamp of the notification. Also see #timestamp=



154
155
156
# File 'lib/google4r/checkout/notifications.rb', line 154

def timestamp
  @timestamp
end