Class: Google4R::Checkout::RefundOrderCommand

Inherits:
Command
  • Object
show all
Defined in:
lib/google4r/checkout/commands.rb

Overview

The RefundOrderCommand instructs Google Checkout to refund an order

Constant Summary

Constants inherited from Command

Command::CHECKOUT_API_URL, Command::ORDER_PROCESSING_API_URL, Command::PRODUCTION_URL_PREFIX, Command::SANDBOX_URL_PREFIX

Instance Attribute Summary collapse

Attributes inherited from Command

#command_tag_name, #frontend, #google_order_number

Instance Method Summary collapse

Methods inherited from Command

#initialize, #send_to_google_checkout

Constructor Details

This class inherits a constructor from Google4R::Checkout::Command

Instance Attribute Details

#amountObject

The amount to refund, optional, Money



317
318
319
# File 'lib/google4r/checkout/commands.rb', line 317

def amount
  @amount
end

#commentObject

A comment related to the refunded order, String of maximum 140 characters, optional



323
324
325
# File 'lib/google4r/checkout/commands.rb', line 323

def comment
  @comment
end

#reasonObject

The reason that the order is to be refunded, String of maximum 140 characters, required



320
321
322
# File 'lib/google4r/checkout/commands.rb', line 320

def reason
  @reason
end

Instance Method Details

#to_xmlObject



325
326
327
# File 'lib/google4r/checkout/commands.rb', line 325

def to_xml
  RefundOrderCommandXmlGenerator.new(self).generate
end