Class: Google4R::Checkout::SendBuyerMessageCommand
- Defined in:
- lib/google4r/checkout/commands.rb
Overview
The SendBuyerMessageCommand instructs Google Checkout to place a message in the customer's Google Checkout account.
Constant Summary
Constants inherited from Command
Command::CHECKOUT_API_URL, Command::ORDER_PROCESSING_API_URL, Command::PRODUCTION_URL_PREFIX, Command::SANDBOX_URL_PREFIX
Instance Attribute Summary collapse
-
#message ⇒ Object
The message to the customer.
-
#send_email ⇒ Object
if google checkout should email buyer to say order is dispatched.
Attributes inherited from Command
#command_tag_name, #frontend, #google_order_number
Instance Method Summary collapse
Methods inherited from Command
#initialize, #send_to_google_checkout
Constructor Details
This class inherits a constructor from Google4R::Checkout::Command
Instance Attribute Details
#message ⇒ Object
The message to the customer
405 406 407 |
# File 'lib/google4r/checkout/commands.rb', line 405 def end |
#send_email ⇒ Object
if google checkout should email buyer to say order is dispatched
408 409 410 |
# File 'lib/google4r/checkout/commands.rb', line 408 def send_email @send_email end |
Instance Method Details
#to_xml ⇒ Object
410 411 412 |
# File 'lib/google4r/checkout/commands.rb', line 410 def to_xml SendBuyerMessageCommandXmlGenerator.new(self).generate end |