Class: Google4R::Checkout::TrackingData
- Inherits:
-
Object
- Object
- Google4R::Checkout::TrackingData
- Defined in:
- lib/google4r/checkout/shared.rb
Overview
TrackingData instances are used in Line-item shipping commands
Instance Attribute Summary collapse
-
#carrier ⇒ Object
readonly
The name of the company responsible for shipping the item.
-
#tracking_number ⇒ Object
readonly
The shipper's tracking number that is associated with an order.
Instance Method Summary collapse
-
#initialize(carrier, tracking_number) ⇒ TrackingData
constructor
A new instance of TrackingData.
Constructor Details
#initialize(carrier, tracking_number) ⇒ TrackingData
Returns a new instance of TrackingData.
1243 1244 1245 1246 |
# File 'lib/google4r/checkout/shared.rb', line 1243 def initialize(carrier, tracking_number) @carrier = carrier.to_s @tracking_number = tracking_number.to_s end |
Instance Attribute Details
#carrier ⇒ Object (readonly)
The name of the company responsible for shipping the item. Valid values for this tag are DHL, FedEx, UPS, USPS and Other.
1238 1239 1240 |
# File 'lib/google4r/checkout/shared.rb', line 1238 def carrier @carrier end |
#tracking_number ⇒ Object (readonly)
The shipper's tracking number that is associated with an order
1241 1242 1243 |
# File 'lib/google4r/checkout/shared.rb', line 1241 def tracking_number @tracking_number end |